import { Component, Input, OnInit } from '@angular/core';
import { TableModel } from 'src/app/shared/interfaces/table-model.interface';
import { AirportsService } from '../../services/airports.service';
import { Airport } from '../../interfaces/airport.interface';

@Component({
  selector: 'agent-flight-information',
  templateUrl: './flight-information.component.html',
  styleUrls: ['./flight-information.component.css']
})
export class FlightInformationComponent implements OnInit {

  @Input()
  public flightModel: TableModel[] = [];

  public airportModel: TableModel[] = [
    {
      name: 'id',
      title: '#'
    },
    {
      name: 'name',
      title: 'Nombre'
    },
    {
      name: 'location',
      title: 'Ubicacion'
    },
    {
      name: 'code',
      title: 'Codigo'
    }
  ];

  public airports: Airport[] = [];

  public airportOrigin?: Airport;

  public airportDestination?: Airport;

  constructor(private airpotsService: AirportsService) { }

  ngOnInit(): void {
    this.airpotsService.getAll()
      .subscribe(airports => this.airports = airports);
  }

  get airportValueNameOrigin(): string {
    return this.airportOrigin?.name || '';
  }

  get airportValueNameDestination(): string {
    return this.airportDestination?.name || '';
  }

  onSelectAirportOrigin(airport: Airport): void {
    this.airportOrigin = airport;
  }

  onSelectAirportDestination(airport: Airport): void {
    this.airportDestination = airport;
  }
}
