import { Component, OnInit } from '@angular/core';
import { Step } from 'src/app/shared/interfaces/step.interface';
import { TableModel } from 'src/app/shared/interfaces/table-model.interface';
import { PassengerService } from '../../services/passenger.service';
import { Passenger } from '../../interfaces/passenger.interface';
import { TicketType } from '../../interfaces/ticket-type.interface';
import { FlightClass } from '../../interfaces/flight-class.interface';

@Component({
  selector: 'app-reservation-add',
  templateUrl: './reservation-add.component.html',
  styleUrls: ['./reservation-add.component.css']
})
export class ReservationAddComponent implements OnInit{

  public steps: Step[] = [
    {
      id: 1,
      title: 'Información base',
      icon: 'bi-person',
      detail: "Información general de la reserva"
    },
    {
      id: 2,
      title: 'Selección de vuelo',
      icon: 'bi-airplane-fill',
      detail: "Información general de la reserva"
    },
    {
      id: 3,
      title: 'Resumen',
      icon: 'bi-check',
      detail: "Valida la configuración"
    }
  ];

  public flightModel: TableModel[] = [
    {
      name: 'id',
      title: '#'
    },
    {
      name: 'aeroline',
      title: 'Aerolinea'
    },
    {
      name: 'aircraftType',
      title: 'Tipo de avión'
    },
    {
      name: 'flightType',
      title: 'Tipo de vuelo'
    },
    {
      name: 'hourStart',
      title: 'Hora de inicio'
    },
    {
      name: 'hourEnd',
      title: 'Hora de llegada'
    },
    {
      name: 'price',
      title: 'Precio'
    }
  ];

  public passengers: Passenger[] = [];

  constructor(private passengersService: PassengerService) { }

  ngOnInit(): void {
    this.passengersService.getAll()
      .subscribe(passengers => this.passengers = passengers);
  }

  public stepIndex: number = 0;

  nextStep(): void {
    if (this.stepIndex === this.steps.length) return;
    this.stepIndex++;
  }

  prevStep(): void {
    if (this.stepIndex === 0) return;
    this.stepIndex--;
  }

  isFirstStep(): boolean {
    return this.stepIndex === 0;
  }

  isLastStep(): boolean {
    return this.stepIndex === this.steps.length - 1;
  }
}
