import { Component, Input } from '@angular/core';
import { FormGroup } from '@angular/forms';
import { max, min } from 'rxjs';

@Component({
  selector: 'shared-input-validator',
  templateUrl: './input-validator.component.html',
  styleUrls: ['./input-validator.component.css']
})
export class InputValidatorComponent {

  @Input()
  public formGroup: FormGroup = new FormGroup({});

  @Input()
  public field: string = '';

  @Input()
  public getValidatorLength: Function = (field: string): {min: string, max: string} => ({min: '', max: ''});

  isValidateField(field: string): boolean | null {
    return this.formGroup.controls[field]? this.formGroup.controls[field].errors && this.formGroup.controls[field].touched : null;
  }

  hasTypeError(field: string, type: string): boolean | null {
    return this.formGroup.controls[field]? this.formGroup.controls[field].hasError(type) && this.formGroup.controls[field].touched : null;
  }

  getFieldError(field: string): string | null {
    if (!this.formGroup.controls[field]) null;
    const errors = this.formGroup.controls[field].errors || {};

    for (const key of Object.keys(errors)) {
      switch (key) {
        case 'required':
          return 'Este campo es requerido';
        case 'email':
          return 'El email no es valido';
        case 'minlength':
          return `El minimo de caracteres es ${errors[key].requiredLength}`;
        case 'maxlength':
          return `El maximo de caracteres es ${errors[key].requiredLength}`;
      }
    }
    return null;
  }

  get displayStyle(): string {
    return this.isValidateField(this.field) ? 'justify-content-between' : 'justify-content-end';
  }
}
