import { Component, EventEmitter, Input, OnChanges, OnInit, Output, SimpleChanges } from '@angular/core';
import { TablePagination } from '../../interfaces/table-pagination.interface';
import { ThisReceiver } from '@angular/compiler';

@Component({
  selector: 'shared-table-paginator',
  templateUrl: './table-paginator.component.html',
  styleUrls: ['./table-paginator.component.css']
})
export class TablePaginatorComponent {

  @Output()
  public onReloadData: EventEmitter<void> = new EventEmitter();

  @Output()
  public onChangePagination: EventEmitter<TablePagination> = new EventEmitter<TablePagination>();

  @Input()
  public tableData: any[] = [];

  public numberOfItemsPerPage: number = 5;

  public itemsPerPage: number[] = [5, 10, 15];

  public page: number = 1;

  get totalPage(): number {
    return this.tableData.length >= this.numberOfItemsPerPage? Math.ceil(this.tableData.length / this.numberOfItemsPerPage) : 1;
  }

  ngOnInit(): void {
    this.onChangePagination.emit({init: this.initItem, end: this.endItem});
  }

  get initItem() {
    return this.tableData.length == 0? 0 : this.totalPage >= 1 || this.tableData.length == 0? ((this.page - 1) * this.numberOfItemsPerPage) + 1 : 0;
  }

  get endItem() {
    return this.totalPage >= 1? this.page != this.totalPage? this.page * this.numberOfItemsPerPage: this.tableData.length : 0;
  }

  nextPage(): void {
    if (this.page === this.totalPage) return;
    this.page += 1;
    this.onChangePagination.emit({init: this.initItem, end: this.endItem});
  }

  prevPage(): void {
    if (this.page === 1) return;
    this.page -= 1;
    this.onChangePagination.emit({init: this.initItem, end: this.endItem});
  }

  getItemsPerPage(value: string): void {
    this.numberOfItemsPerPage = parseInt(value);
  }

  onEmitReloadData(): void {
    this.onReloadData.emit();
  }
}
